Localization - Betty documentation

Hide navigation sidebar
Hide table of contents sidebar
Skip to content
Back to top
View this page
Toggle table of contents sidebar

# Localization

## gettext

Betty uses gettext to manage its translations:

- Betty will compile `*.mo` files internally. You will never have to do this manually

- Betty will manage `*.pot` and `*.po` files automatically if you use the `*-translations` commands

- You will have to add translations to `*.po` files yourself

## Working on translatable strings

Run `betty dev-update-translations` to update the translations files with the changes you made.

## Translating Betty

The Betty community uses Weblate to coordinate translations of its built-in translatable strings. To add or improve translations, create a Weblate account, navigate to the Betty translation you want to contribute to, and start translating.

Changes made in Weblate will be synchronized back to Betty in the form of pull requests once every 24 hours.